@@ -60,7 +60,7 @@ walk_call <- function(expr, results, locals, allowed_globals) { # nolint
   if (name == "local") {
     locals <- ht_clone(locals)
   }
-  if (name == "$") {
+  if (name %in% c("$", "@")) {
     expr[[3]] <- substitute()
   }
   if (walk_base(expr, results, locals, allowed_globals, name)) {
@@ -213,7 +213,7 @@ analyze_assign <- function(expr, results, locals, allowed_globals) {
       ht_set(locals, expr$x)
     }
   } else {
-    analyze_global(expr$x, results, locals, allowed_globals)
+    ignore(walk_code)(expr$x, results, locals, allowed_globals)
   }
   expr$x <- NULL
   walk_recursive(expr, results, locals, allowed_globals)
@@ -380,12 +380,13 @@ get_tangled_text <- function(doc) {
 # of the R language definition manual:
 # https://cran.r-project.org/doc/manuals/R-lang.html#Subset-assignment
 flatten_assignment <- function(e) {
-  if (typeof(e) == "language") {
-    c(evalseq(e[[2]]), apdef(e))
-  } else {
-    # Was list(NULL, NULL), but that seems unnecessary here. # nolint
-    NULL
+  if (typeof(e) != "language") {
+    return()
   }
+  if (e[[1]] == quote(`$`) || e[[1]] == quote(`@`)) {
+    return(evalseq(e[[2]]))
+  }
+  c(evalseq(e[[2]]), apdef(e))
 }
 
 apdef <- function(e) {
