@@ -65,30 +65,28 @@
 #' @export
 #' @return nothing
 #' @inheritParams drake_config
-#' @param config An optional configured workflow from [drake_config()].
-#'   If you supply `config` to `make()`, you must not supply any
-#'   additional arguments.
+#' @param config Deprecated.
 #' @examples
 #' \dontrun{
 #' isolate_example("Quarantine side effects.", {
 #' if (suppressWarnings(require("knitr"))) {
 #' load_mtcars_example() # Get the code with drake_example("mtcars").
 #' config <- drake_config(my_plan)
-#' outdated(config) # Which targets need to be (re)built?
+#' outdated(my_plan) # Which targets need to be (re)built?
 #' make(my_plan) # Build what needs to be built.
-#' outdated(config) # Everything is up to date.
+#' outdated(my_plan) # Everything is up to date.
 #' # Change one of your imported function dependencies.
 #' reg2 = function(d) {
 #'   d$x3 = d$x^3
 #'   lm(y ~ x3, data = d)
 #' }
-#' outdated(config) # Some targets depend on reg2().
+#' outdated(my_plan) # Some targets depend on reg2().
 #' make(my_plan) # Rebuild just the outdated targets.
-#' outdated(config) # Everything is up to date again.
+#' outdated(my_plan) # Everything is up to date again.
 #' if (requireNamespace("visNetwork", quietly = TRUE)) {
-#' vis_drake_graph(config) # See how they fit in an interactive graph.
+#' vis_drake_graph(my_plan) # See how they fit in an interactive graph.
 #' make(my_plan, cache_log_file = TRUE) # Write a CSV log file this time.
-#' vis_drake_graph(config) # The colors changed in the graph.
+#' vis_drake_graph(my_plan) # The colors changed in the graph.
 #' # Run targets in parallel:
 #' # options(clustermq.scheduler = "multicore") # nolint
 #' # make(my_plan, parallelism = "clustermq", jobs = 2) # nolint
@@ -164,72 +162,85 @@ make <- function(
   recoverable = TRUE,
   curl_handles = list(),
   max_expand = NULL,
-  log_build_times = TRUE
+  log_build_times = TRUE,
+  format = NULL,
+  lock_cache = TRUE
 ) {
-  check_make_call(match.call())
   force(envir)
-  if (is.null(config)) {
-    config <- drake_config(
-      plan = plan,
-      targets = targets,
-      envir = envir,
-      seed = seed,
-      verbose = verbose,
-      hook = hook,
-      parallelism = parallelism,
-      jobs = jobs,
-      jobs_preprocess = jobs_preprocess,
-      packages = packages,
-      lib_loc = lib_loc,
-      prework = prework,
-      prepend = prepend,
-      command = command,
-      args = args,
-      recipe_command = recipe_command,
-      log_progress = log_progress,
-      cache = cache,
-      fetch_cache = fetch_cache,
-      timeout = timeout,
-      cpu = cpu,
-      elapsed = elapsed,
-      retries = retries,
-      force = force,
-      graph = graph,
-      trigger = trigger,
-      skip_targets = skip_targets,
-      skip_imports = skip_imports,
-      skip_safety_checks = skip_safety_checks,
-      lazy_load = lazy_load,
-      session_info = session_info,
-      cache_log_file = cache_log_file,
-      caching = caching,
-      keep_going = keep_going,
-      session = session,
-      pruning_strategy = pruning_strategy,
-      makefile_path = makefile_path,
-      console_log_file = console_log_file,
-      ensure_workers = ensure_workers,
-      garbage_collection = garbage_collection,
-      template = template,
-      sleep = sleep,
-      hasty_build = hasty_build,
-      memory_strategy = memory_strategy,
-      layout = layout,
-      spec = spec,
-      lock_envir = lock_envir,
-      history = history,
-      recover = recover,
-      recoverable = recoverable,
-      curl_handles = curl_handles,
-      max_expand = max_expand,
-      log_build_times = log_build_times
-    )
-  }
+  deprecate_arg(config, "config")
+  config <- config %|||% drake_config(
+    plan = plan,
+    targets = targets,
+    envir = envir,
+    verbose = verbose,
+    hook = hook,
+    cache = cache,
+    fetch_cache = fetch_cache,
+    parallelism = parallelism,
+    jobs = jobs,
+    jobs_preprocess = jobs_preprocess,
+    packages = packages,
+    lib_loc = lib_loc,
+    prework = prework,
+    prepend = prepend,
+    command = command,
+    args = args,
+    recipe_command = recipe_command,
+    log_progress = log_progress,
+    skip_targets = skip_targets,
+    timeout = timeout,
+    cpu = cpu,
+    elapsed = elapsed,
+    retries = retries,
+    force = force,
+    graph = graph,
+    trigger = trigger,
+    skip_imports = skip_imports,
+    skip_safety_checks = skip_safety_checks,
+    lazy_load = lazy_load,
+    session_info = session_info,
+    cache_log_file = cache_log_file,
+    seed = seed,
+    caching = caching,
+    keep_going = keep_going,
+    session = session,
+    pruning_strategy = pruning_strategy,
+    makefile_path = makefile_path,
+    console_log_file = console_log_file,
+    ensure_workers = ensure_workers,
+    garbage_collection = garbage_collection,
+    template = template,
+    sleep = sleep,
+    hasty_build = hasty_build,
+    memory_strategy = memory_strategy,
+    layout = layout,
+    spec = spec,
+    lock_envir = lock_envir,
+    history = history,
+    recover = recover,
+    recoverable = recoverable,
+    curl_handles = curl_handles,
+    max_expand = max_expand,
+    log_build_times = log_build_times,
+    format = format,
+    lock_cache = lock_cache
+  )
+  make_impl(config)
+}
+
+#' @title Internal function with a drake_config() argument
+#' @export
+#' @keywords internal
+#' @description Not a user-side function.
+#' @param config a [drake_config()] object.
+make_impl <- function(config) {
   config$logger$minor("begin make()")
   on.exit(config$logger$minor("end make()"), add = TRUE)
   runtime_checks(config = config)
-  config$cache$lock()
-  on.exit(config$cache$unlock(), add = TRUE)
+  if (config$lock_cache) {
+    config$cache$lock()
+    on.exit(config$cache$unlock(), add = TRUE)
+  }
   config$running_make <- TRUE
   config$ht_dynamic <- ht_new()
   config$ht_dynamic_size <- ht_new()
@@ -238,7 +249,6 @@ make <- function(
   config$envir_loaded <- new.env(hash = FALSE, parent = emptyenv())
   config$cache$reset_memo_hash()
   on.exit(config$cache$reset_memo_hash(), add = TRUE)
-  config$envir_subtargets[[drake_envir_marker]] <- TRUE
   config$cache$set(key = "seed", value = config$seed, namespace = "session")
   if (config$log_progress) {
     config$cache$clear(namespace = "progress")
@@ -304,7 +314,7 @@ run_external_backend <- function(config) {
 }
 
 outdated_subgraph <- function(config) {
-  outdated <- outdated(config, do_prework = FALSE, make_imports = FALSE)
+  outdated <- outdated_impl(config, do_prework = FALSE, make_imports = FALSE)
   config$logger$minor("isolate oudated targets")
   igraph::induced_subgraph(graph = config$graph, vids = outdated)
 }
@@ -453,20 +463,6 @@ drake_cache_log_file_ <- function(
   )
 }
 
-check_make_call <- function(call) {
-  x <- names(call)
-  if ("config" %in% names(call) && sum(nzchar(x)) > 1L) {
-    warning(
-      "if you supply a ", shQuote("config"),
-      " argument to ", shQuote("make()"),
-      " then all additional arguments are ignored. ",
-      "For example, in ", shQuote("make(config = config, verbose = 0L)"),
-      "verbosity remains at ", shQuote("config$logger$verbose"), ".",
-      call. = FALSE
-    )
-  }
-}
-
 runtime_checks <- function(config) {
   assert_config(config)
   if (identical(config$skip_safety_checks, TRUE)) {
