@@ -138,10 +138,26 @@ longest_match <- function(choices, against) {
   matches[which.max(nchar(matches))]
 }
 
+vcapply <- function(X, FUN, ...) {
+  vapply(X, FUN, FUN.VALUE = character(1), ...)
+}
+
 vlapply <- function(X, FUN, ...) {
   vapply(X, FUN, FUN.VALUE = logical(1), ...)
 }
 
+safe_vec_c <- function(...) {
+  tryCatch(
+    vctrs::vec_c(...),
+    vctrs_error_scalar_type = function(e) {
+      list(...)
+    },
+    error = function(e) {
+      stop(e)
+    }
+  )
+}
+
 num_unique <- function(x) {
   length(unique(x))
 }
@@ -345,6 +361,16 @@ safe_is_na <- function(x) {
   tryCatch(is.na(x), error = error_false, warning = error_false)
 }
 
+min_str <- function(x) {
+  n_spaces <- nchar(names(x))
+  n_spaces <- max(n_spaces) - n_spaces
+  for (index in seq_along(x)) {
+    name <- names(x)[index]
+    spaces <- paste(rep(" ", n_spaces[index]), collapse = "")
+    cat(" $", name, ":", spaces, class(x[[name]]), "\n")
+  }
+}
+
 # From lintr
 `%||%` <- function(x, y) {
   if (is.null(x) || length(x) <= 0) {
