@@ -309,10 +309,10 @@ test_with_dir("user-defined S3 (#959)", {
     history = FALSE,
     cache = storr::storr_environment()
   )
-  out <- sort(deps_target(dostuff, config)$name)
+  out <- sort(deps_target_impl(dostuff, config)$name)
   exp <- sort(c("do.stuff.class1", "do.stuff.class3"))
   expect_equal(out, exp)
-    dostuff <- function(x) {
+  dostuff <- function(x) {
     do.stuff.class2 <- 40 # nolint
     if (1 == 1) {
       UseMethod(object = x, generic = "do.stuff")
@@ -325,17 +325,17 @@ test_with_dir("user-defined S3 (#959)", {
     history = FALSE,
     cache = storr::storr_environment()
   )
-  out <- sort(deps_target(dostuff, config)$name)
+  out <- sort(deps_target_impl(dostuff, config)$name)
   exp <- sort(c("do.stuff.class1", "do.stuff.class3"))
-  make(config = config)
+  make_impl(config = config)
   expect_equal(justbuilt(config), "x")
-  make(config = config)
+  make_impl(config = config)
   expect_equal(justbuilt(config), character(0))
   do.stuff.class1 <- function(...) { # nolint
     message(123)
     invisible()
   }
-  make(config = config)
+  make_impl(config = config)
   expect_equal(justbuilt(config), "x")
   dostuff <- function(...) {
     do.stuff.class2 <- 40 # nolint
@@ -350,7 +350,7 @@ test_with_dir("user-defined S3 (#959)", {
     history = FALSE,
     cache = storr::storr_environment()
   )
-  expect_equal(deps_target(dostuff, config)$name, character(0))
+  expect_equal(deps_target_impl(dostuff, config)$name, character(0))
   dostuff <- function(x) {
     UseMethod(paste0("do", ".", "stuff"))
   }
@@ -359,7 +359,7 @@ test_with_dir("user-defined S3 (#959)", {
     history = FALSE,
     cache = storr::storr_environment()
   )
-  expect_equal(deps_target(dostuff, config)$name, character(0))
+  expect_equal(deps_target_impl(dostuff, config)$name, character(0))
 })
 
 test_with_dir("unparsable commands are handled correctly", {
@@ -368,7 +368,7 @@ test_with_dir("unparsable commands are handled correctly", {
   expect_error(deps_code(x))
 })
 
-test_with_dir("dot symbol is illegal", {
+test_with_dir("bad target names", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   expect_equal(
     sort(deps_code("sqrt(x + y + .)")$name),
@@ -388,10 +388,10 @@ test_with_dir("dot symbol is illegal", {
   expect_false(exists(".", envir = e))
   config <- drake_config(plan)
   plan <- drake_plan(
-    . = 1,
+    .gitignore = 1,
     y = 2,
     a = sqrt(x + y),
-    b = subset(complete.cases(.))
+    b = subset(complete.cases(.gitignore))
   )
   expect_error(drake_config(plan), "cannot be target names")
 })
@@ -450,7 +450,7 @@ test_with_dir("file_out() and knitr_in(): commands vs imports", {
   )
 })
 
-test_with_dir("deps_code() and deps_target()", {
+test_with_dir("deps_code() and deps_target_impl()", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   expect_equal(nrow(deps_code("")), 0)
   expect_equal(length(cds_command_dependencies(NA)), 0)
@@ -496,20 +496,20 @@ test_with_dir("deps_code() and deps_target()", {
     sort(deps_code(my_plan$command[[5]])$name),
     sort(c("read.table", "file_in"))
   )
-  expect_true(!nrow(deps_target(x, config)))
+  expect_true(!nrow(deps_target_impl(x, config)))
   expect_equal(
-    sort(deps_target(my_target, config)$name),
+    sort(deps_target_impl(my_target, config)$name),
     sort(c("tracked_input_file.rds", "x")))
   expect_equal(
-    sort(deps_target(return_value, config)$name),
+    sort(deps_target_impl(return_value, config)$name),
     sort(c("f", "x"))
   )
   expect_equal(
-    sort(deps_target(botched, config)$name),
+    sort(deps_target_impl(botched, config)$name),
     character(0)
   )
   expect_equal(
-    sort(deps_target(meta, config)$name),
+    sort(deps_target_impl(meta, config)$name),
     sort("file_in"))
 })
 
@@ -560,14 +560,14 @@ test_with_dir("Vectorized nested functions work", {
   expect_equal(readd(a), 8:17)
   k <- readd(f)
   expect_true(is.character(k))
-  expect_equal(character(0), outdated(config))
+  expect_equal(character(0), outdated_impl(config))
   config$envir$y <- 8
-  expect_equal("a", outdated(config))
+  expect_equal("a", outdated_impl(config))
 
   # Target "a" should react.
   testrun(config)
   config <- testconfig(config)
-  expect_equal(character(0), outdated(config))
+  expect_equal(character(0), outdated_impl(config))
   expect_equal(readd(a), 9:18)
 
   # Change a vectorized function and see target "a" react.
@@ -581,12 +581,12 @@ test_with_dir("Vectorized nested functions work", {
   expect_equal(readd(a), 12:21)
 })
 
-test_with_dir("deps_target()", {
+test_with_dir("deps_target_impl()", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   skip_if_not_installed("knitr")
   load_mtcars_example()
   config <- drake_config(my_plan, cache = storr::storr_environment())
-  d1 <- deps_target(report, config = config)
+  d1 <- deps_target_impl(report, config = config)
   d1 <- as.data.frame(d1[order(d1$name), ])
   d2 <- data.frame(
     name = c(
@@ -596,13 +596,15 @@ test_with_dir("deps_target()", {
     stringsAsFactors = FALSE
   )
   d2 <- d2[order(d2$name), ]
+  d1$hash <- NULL
   expect_equivalent(d1, d2)
-  d <- deps_target(regression1_small, config = config)
+  d <- deps_target_impl(regression1_small, config = config)
   expect_equal(sort(d$name), sort(c("reg1", "small")))
   expect_equal(d$type, rep("globals", 2))
 })
 
 test_with_dir("self-referential commands and imports", {
+  skip_on_cran()
   f <- function(x, ...) {
     x <- f
   }
@@ -639,7 +641,7 @@ test_with_dir("ignore() suppresses updates", {
   )
   expect_equal(justbuilt(con), "x")
   con$envir$arg <- con$envir$arg + 1
-  make(config = con)
+  make_impl(config = con)
   expect_equal(justbuilt(con), "x")
 
   # With ignore()
@@ -656,13 +658,13 @@ test_with_dir("ignore() suppresses updates", {
   expect_equal(justbuilt(con), "x")
   con$envir$arg <- con$envir$arg + 1
   con$cache$clear(namespace = "progress")
-  make(config = con)
+  make_impl(config = con)
   expect_equal(justbuilt(con), character(0))
 
   con$envir$arg2 <- con$envir$arg + 1234
   con$plan <- drake_plan(x = sqrt( ignore  (arg2 ) + 123)) # nolint
   con$cache$clear(namespace = "progress")
-  make(config = con)
+  make_impl(config = con)
   expect_equal(justbuilt(con), character(0))
 })
 
@@ -868,7 +870,7 @@ test_with_dir("ignore() inside special functions", {
   for (x in letters[2:6]) {
     for (y in 1:5) {
       target <- paste0(x, y)
-      deps <- deps_target(target, config, character_only = TRUE)$name
+      deps <- deps_target_impl(target, config, character_only = TRUE)$name
       if (y < 3) {
         expect_equal(deps, "a")
       } else {
@@ -879,6 +881,7 @@ test_with_dir("ignore() inside special functions", {
 })
 
 test_with_dir("no_deps() in a command", {
+  skip_on_cran()
   plan <- drake_plan(y = sqrt(no_deps(x)))
   cache <- storr::storr_environment()
   config <- drake_config(plan, cache = cache)
@@ -894,6 +897,7 @@ test_with_dir("no_deps() in a command", {
 })
 
 test_with_dir("no_deps() in a function", {
+  skip_on_cran()
   y <- 1
   f <- function(x) {
     no_deps({
@@ -1002,7 +1006,7 @@ test_with_dir("namespaced drake_plan works", {
   expect_true(all(ns %in% setdiff(cached(targets_only = FALSE),
                                   cached(targets_only = TRUE))))
   expect_equal(
-    outdated(config),
+    outdated_impl(config),
     character(0)
   )
 })
@@ -1030,3 +1034,28 @@ test_with_dir("standardizing Rcpp functions (#806)", {
 test_with_dir("utils for code analysis fns", {
   expect_equal(pair_text("x", c("y", "z")), c("xy", "xz"))
 })
+
+test_with_dir("handle @ (#1130)", {
+  expect_equal(deps_code(quote(x@y))$name, "x")
+})
+
+test_with_dir("handle calls in analyze_assign() (#1119)", {
+  test <- function(input) {
+    assign(paste0(input, x, "var"), 1)
+  }
+  expect_silent(out <- deps_code(test))
+  expect_equal(nrow(out), 3)
+  expect_equal(sort(out$name), sort(c("assign", "paste0", "x")))
+})
+
+test_with_dir("$<-() and @<-() (#1144)", {
+  f <- function() {
+    x$y <- 1
+    x@y <- 1
+  }
+  expect_equal(deps_code(f)$name, "x")
+  f <- function() {
+    g(x)$y <- 1
+  }
+  expect_equal(sort(deps_code(f)$name), sort(c("g", "x")))
+})
