@@ -60,7 +60,7 @@ test_with_dir("triggers in plan override make(trigger = whatever)", {
   config <- drake_config(plan, session_info = FALSE)
   expect_equal(sort(justbuilt(config)), c("x", "y"))
   saveRDS(2, "file.rds")
-  expect_equal(sort(outdated(config)), c("x", "y"))
+  expect_equal(sort(outdated_impl(config)), c("x", "y"))
   make(plan, trigger = trigger(file = FALSE), session_info = FALSE)
   config <- drake_config(
     plan, trigger = trigger(file = FALSE), session_info = FALSE)
@@ -145,17 +145,17 @@ test_with_dir("can detect trigger deps without reacting to them", {
   deps <- c(reencode_path(c("file.rds", "knitr.Rmd")), "f")
   expect_true(all(deps %in% igraph::V(config$graph)$name))
   expect_equal(sort(deps_graph("x", config$graph)), sort(deps))
-  expect_equal(outdated(config), "x")
-  make(config = config)
+  expect_equal(outdated_impl(config), "x")
+  make_impl(config = config)
   expect_equal(justbuilt(config), "x")
-  expect_equal(outdated(config), character(0))
-  make(config = config)
+  expect_equal(outdated_impl(config), character(0))
+  make_impl(config = config)
   nobuild(config)
   f <- function(x) {
     identity(x) || FALSE
   }
-  expect_equal(outdated(config), character(0))
-  make(config = config)
+  expect_equal(outdated_impl(config), character(0))
+  make_impl(config = config)
   nobuild(config)
 })
 
@@ -184,17 +184,17 @@ test_with_dir("same, but with global trigger", {
   deps <- c(reencode_path(c("file.rds", "knitr.Rmd")), "f")
   expect_true(all(deps %in% igraph::V(config$graph)$name))
   expect_equal(sort(deps_graph("x", config$graph)), sort(deps))
-  expect_equal(outdated(config), "x")
-  make(config = config)
+  expect_equal(outdated_impl(config), "x")
+  make_impl(config = config)
   expect_equal(justbuilt(config), "x")
-  expect_equal(outdated(config), character(0))
-  make(config = config)
+  expect_equal(outdated_impl(config), character(0))
+  make_impl(config = config)
   nobuild(config)
   f <- function(x) {
     identity(x) || FALSE
   }
-  expect_equal(outdated(config), character(0))
-  make(config = config)
+  expect_equal(outdated_impl(config), character(0))
+  make_impl(config = config)
   nobuild(config)
 })
 
@@ -230,7 +230,7 @@ test_with_dir("trigger does not block out command deps", {
   deps <- c(reencode_path("file.rds"), reencode_path("knitr.Rmd"), "f")
   expect_true(all(deps %in% igraph::V(config$graph)$name))
   expect_equal(sort(deps_graph("x", config$graph)), sort(deps))
-  expect_equal(outdated(config), "x")
+  expect_equal(outdated_impl(config), "x")
   make(
     plan, session_info = FALSE,
     cache = config$cache,
@@ -238,22 +238,22 @@ test_with_dir("trigger does not block out command deps", {
     memory_strategy = "preclean"
   )
   expect_equal(justbuilt(config), "x")
-  expect_equal(outdated(config), character(0))
-  make(config = config)
+  expect_equal(outdated_impl(config), character(0))
+  make_impl(config = config)
   nobuild(config)
   f <- function(x) {
     identity(x) || FALSE
   }
-  expect_equal(outdated(config), "x")
-  make(config = config)
+  expect_equal(outdated_impl(config), "x")
+  make_impl(config = config)
   expect_equal(justbuilt(config), "x")
   writeLines("456", "knitr.Rmd")
-  expect_equal(outdated(config), "x")
-  make(config = config)
+  expect_equal(outdated_impl(config), "x")
+  make_impl(config = config)
   expect_equal(justbuilt(config), "x")
   saveRDS(2, "file.rds")
-  expect_equal(outdated(config), "x")
-  make(config = config)
+  expect_equal(outdated_impl(config), "x")
+  make_impl(config = config)
   expect_equal(justbuilt(config), "x")
 })
 
@@ -287,7 +287,7 @@ test_with_dir("same, but with global change trigger", {
   deps <- c(file_store("file.rds"), file_store("knitr.Rmd"), "f")
   expect_true(all(deps %in% igraph::V(config$graph)$name))
   expect_equal(sort(deps_graph("x", config$graph)), sort(deps))
-  expect_equal(outdated(config), "x")
+  expect_equal(outdated_impl(config), "x")
   make(
     plan,
     session_info = FALSE,
@@ -305,7 +305,7 @@ test_with_dir("same, but with global change trigger", {
     memory_strategy = "preclean"
   )
   expect_equal(justbuilt(config), "x")
-  expect_equal(outdated(config), character(0))
+  expect_equal(outdated_impl(config), character(0))
   make(
     plan,
     session_info = FALSE,
@@ -326,16 +326,16 @@ test_with_dir("same, but with global change trigger", {
   f <- function(x) {
     identity(x) || FALSE
   }
-  expect_equal(outdated(config), "x")
-  make(config = config)
+  expect_equal(outdated_impl(config), "x")
+  make_impl(config = config)
   expect_equal(justbuilt(config), "x")
   writeLines("456", "knitr.Rmd")
-  expect_equal(outdated(config), "x")
-  make(config = config)
+  expect_equal(outdated_impl(config), "x")
+  make_impl(config = config)
   expect_equal(justbuilt(config), "x")
   saveRDS(2, "file.rds")
-  expect_equal(outdated(config), "x")
-  make(config = config)
+  expect_equal(outdated_impl(config), "x")
+  make_impl(config = config)
   expect_equal(justbuilt(config), "x")
 })
 
@@ -457,7 +457,7 @@ test_with_dir("trigger components react appropriately", {
     log_progress = TRUE
   )
   expect_equal(sort(justbuilt(config)), sort(plan$target))
-  expect_equal(outdated(config), "condition")
+  expect_equal(outdated_impl(config), "condition")
   simple_plan <- plan
   simple_plan$trigger <- NULL
   make(
@@ -472,61 +472,61 @@ test_with_dir("trigger components react appropriately", {
 
   # Condition trigger
   for (i in 1:2) {
-    expect_equal(sort(outdated(config)), "condition")
-    make(config = config)
+    expect_equal(sort(outdated_impl(config)), "condition")
+    make_impl(config = config)
     expect_equal(sort(justbuilt(config)), "condition")
   }
   saveRDS(FALSE, "condition.rds")
-  expect_equal(outdated(simple_config), character(0))
-  expect_equal(outdated(config), character(0))
+  expect_equal(outdated_impl(simple_config), character(0))
+  expect_equal(outdated_impl(config), character(0))
   for (i in 1:2) {
-    make(config = config)
+    make_impl(config = config)
     nobuild(config)
   }
 
   # Change trigger
   saveRDS(2, "change.rds")
-  expect_equal(sort(outdated(config)), "change")
-  expect_equal(outdated(simple_config), character(0))
-  make(config = config)
+  expect_equal(sort(outdated_impl(config)), "change")
+  expect_equal(outdated_impl(simple_config), character(0))
+  make_impl(config = config)
   expect_equal(sort(justbuilt(config)), "change")
-  expect_equal(outdated(config), character(0))
-  expect_equal(outdated(simple_config), character(0))
+  expect_equal(outdated_impl(config), character(0))
+  expect_equal(outdated_impl(simple_config), character(0))
 
   # File trigger: input files
   saveRDS(2, "file.rds")
-  expect_equal(sort(outdated(config)), "file")
-  make(config = config)
+  expect_equal(sort(outdated_impl(config)), "file")
+  make_impl(config = config)
   expect_equal(sort(justbuilt(config)), "file")
   expect_equal(
-    sort(outdated(simple_config)),
+    sort(outdated_impl(simple_config)),
     sort(setdiff(plan$target, "file"))
   )
-  expect_equal(outdated(config), character(0))
+  expect_equal(outdated_impl(config), character(0))
 
   # File trigger: knitr files
   writeLines("5678", "report.Rmd")
-  expect_equal(sort(outdated(config)), "file")
-  make(config = config)
+  expect_equal(sort(outdated_impl(config)), "file")
+  make_impl(config = config)
   expect_equal(sort(justbuilt(config)), "file")
   expect_equal(
-    sort(outdated(simple_config)),
+    sort(outdated_impl(simple_config)),
     sort(setdiff(plan$target, "file"))
   )
-  expect_equal(outdated(config), character(0))
+  expect_equal(outdated_impl(config), character(0))
 
   # File trigger: output files
   for (target in plan$target) {
     saveRDS("1234", paste0("out_", target, ".rds"))
   }
-  expect_equal(sort(outdated(config)), "file")
-  make(config = config)
+  expect_equal(sort(outdated_impl(config)), "file")
+  make_impl(config = config)
   expect_equal(sort(justbuilt(config)), "file")
   expect_equal(
-    sort(outdated(simple_config)),
+    sort(outdated_impl(simple_config)),
     sort(setdiff(plan$target, "file"))
   )
-  expect_equal(outdated(config), character(0))
+  expect_equal(outdated_impl(config), character(0))
 
   # Done with the change trigger
   plan <- plan[1:5, ]
@@ -541,7 +541,7 @@ test_with_dir("trigger components react appropriately", {
     verbose = 0L, caching = caching, log_progress = TRUE,
     session_info = FALSE
   )
-  make(config = simple_config)
+  make_impl(config = simple_config)
 
   # Command trigger
   new_commands <- paste0("{
@@ -562,16 +562,16 @@ test_with_dir("trigger components react appropriately", {
     verbose = 0L, caching = caching, log_progress = TRUE,
     session_info = FALSE
   )
-  expect_equal(sort(outdated(config)), "command")
-  make(config = config)
+  expect_equal(sort(outdated_impl(config)), "command")
+  make_impl(config = config)
   expect_equal(sort(justbuilt(config)), "command")
   expect_equal(
-    sort(outdated(simple_config)),
+    sort(outdated_impl(simple_config)),
     sort(setdiff(plan$target, "command"))
   )
-  expect_equal(outdated(config), character(0))
-  make(config = simple_config)
-  expect_equal(outdated(config), character(0))
+  expect_equal(outdated_impl(config), character(0))
+  make_impl(config = simple_config)
+  expect_equal(outdated_impl(config), character(0))
 
   # Depend trigger
   eval(
@@ -580,16 +580,16 @@ test_with_dir("trigger components react appropriately", {
     }),
     envir = e
   )
-  expect_equal(sort(outdated(config)), "depend")
-  make(config = config)
+  expect_equal(sort(outdated_impl(config)), "depend")
+  make_impl(config = config)
   expect_equal(sort(justbuilt(config)), "depend")
   expect_equal(
-    sort(outdated(simple_config)),
+    sort(outdated_impl(simple_config)),
     sort(setdiff(plan$target, "depend"))
   )
-  expect_equal(outdated(config), character(0))
-  make(config = simple_config)
-  expect_equal(outdated(config), character(0))
+  expect_equal(outdated_impl(config), character(0))
+  make_impl(config = simple_config)
+  expect_equal(outdated_impl(config), character(0))
 })
 
 test_with_dir("trigger whitelist mode", {
@@ -615,7 +615,7 @@ test_with_dir("trigger whitelist mode", {
     verbose = 1L, caching = caching, session_info = FALSE
   )
   expect_equal(justbuilt(config), "y")
-  expect_equal(outdated(config), character(0))
+  expect_equal(outdated_impl(config), character(0))
   make(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 1L, caching = caching, session_info = FALSE,
@@ -697,7 +697,7 @@ test_with_dir("trigger blacklist mode", {
     verbose = 1L, caching = caching, session_info = FALSE
   )
   expect_equal(justbuilt(config), "y")
-  expect_equal(outdated(config), character(0))
+  expect_equal(outdated_impl(config), character(0))
   make(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 1L, caching = caching, session_info = FALSE,
@@ -779,7 +779,7 @@ test_with_dir("trigger condition mode", {
     verbose = 1L, caching = caching, session_info = FALSE
   )
   expect_equal(justbuilt(config), "y")
-  expect_equal(outdated(config), character(0))
+  expect_equal(outdated_impl(config), character(0))
   make(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 1L, caching = caching, session_info = FALSE,
