@@ -157,6 +157,7 @@ test_with_dir("run through non-encoder decorated storr methods", {
 })
 
 test_with_dir("garbage collection", {
+  skip_on_cran()
   skip_if(getRversion() < "3.5.0")
   plan <- drake_plan(
     x = target(
@@ -178,6 +179,7 @@ test_with_dir("garbage collection", {
 })
 
 test_with_dir("no special format", {
+  skip_on_cran()
   plan <- drake_plan(y = "normal format")
   make(plan)
   expect_identical(readd(y), "normal format")
@@ -189,10 +191,11 @@ test_with_dir("no special format", {
 })
 
 test_with_dir("illegal format", {
+  skip_on_cran()
   plan <- drake_plan(y = target("bad format", format = "bad format"))
   expect_error(
     drake_config(plan),
-    regexp = "format column of your drake plan can only have values"
+    regexp = "illegal format"
   )
 })
 
@@ -221,6 +224,7 @@ test_with_dir("rds format", {
 })
 
 test_with_dir("rds format with hpc checksum", {
+  skip_on_cran()
   skip_if(getRversion() < "3.5.0")
   skip_if_not_installed("future")
   future::plan(future::sequential)
@@ -277,6 +281,7 @@ test_with_dir("flow with rds format", {
 })
 
 test_with_dir("rds format with environment storr", {
+  skip_on_cran()
   skip_if(getRversion() < "3.5.0")
   plan <- drake_plan(x = target(list(x = letters, y = letters), format = "rds"))
   cache <- storr::storr_environment()
@@ -299,6 +304,7 @@ test_with_dir("rds format with environment storr", {
 })
 
 test_with_dir("rds format and recovery", {
+  skip_on_cran()
   skip_if(getRversion() < "3.5.0")
   plan <- drake_plan(
     x = target({
@@ -361,7 +367,32 @@ test_with_dir("Can save fst data frames", {
   expect_false(is.list(ref))
 })
 
+test_with_dir("Can save fst_tbl tibbles (#1154)", {
+  skip_on_cran()
+  skip_if_not_installed("fst")
+  skip_if_not_installed("tibble")
+  plan <- drake_plan(
+    x = target(
+      tibble::tibble(x = letters, y = letters),
+      format = "fst_tbl"
+    )
+  )
+  make(plan)
+  out <- readd(x)
+  exp <- tibble::tibble(x = letters, y = letters)
+  expect_equal(out, exp)
+  cache <- drake_cache()
+  expect_equal(cache$get_value(cache$get_hash("x")), exp)
+  ref <- cache$storr$get("x")
+  expect_true(inherits(ref, "drake_format"))
+  expect_true(inherits(ref, "drake_format_fst_tbl"))
+  expect_equal(length(ref), 1L)
+  expect_true(nchar(ref) < 100)
+  expect_false(is.list(ref))
+})
+
 test_with_dir("fst format forces data frames", {
+  skip_on_cran()
   skip_if_not_installed("fst")
   plan <- drake_plan(
     x = target(
@@ -371,9 +402,11 @@ test_with_dir("fst format forces data frames", {
   )
   expect_warning(make(plan), regexp = "plain data frame")
   expect_true(inherits(readd(x), "data.frame"))
+  expect_false(inherits(readd(x), "tbl_df"))
 })
 
-test_with_dir("fst format and tibbles", {
+test_with_dir("regular fst format and tibbles", {
+  skip_on_cran()
   skip_if_not_installed("fst")
   skip_if_not_installed("tibble")
   plan <- drake_plan(
@@ -391,6 +424,20 @@ test_with_dir("fst format and tibbles", {
   expect_false(inherits(readd(x), "tibble"))
 })
 
+test_with_dir("fst_tbl format forces tibbles (#1154)", {
+  skip_on_cran()
+  skip_if_not_installed("fst")
+  skip_if_not_installed("tibble")
+  plan <- drake_plan(
+    x = target(
+      list(x = letters, y = letters),
+      format = "fst_tbl"
+    )
+  )
+  expect_warning(make(plan), regexp = "tibble")
+  expect_true(inherits(readd(x), "tbl_df"))
+})
+
 test_with_dir("fst_dt", {
   skip_if_not_installed("data.table")
   skip_if_not_installed("fst")
@@ -419,6 +466,7 @@ test_with_dir("fst_dt", {
 })
 
 test_with_dir("fst_dt format forces data.tables", {
+  skip_on_cran()
   skip_if_not_installed("data.table")
   skip_if_not_installed("fst")
   plan <- drake_plan(
@@ -484,6 +532,7 @@ test_with_dir("diskframe format forces disk.frames", {
 })
 
 test_with_dir("drop format for NULL values (#998)", {
+  skip_on_cran()
   skip_if(getRversion() < "3.5.0")
   f <- function() {
     NULL
@@ -495,6 +544,7 @@ test_with_dir("drop format for NULL values (#998)", {
 })
 
 test_with_dir("decorated storr import (#1015)", {
+  skip_on_cran()
   skip_if(getRversion() < "3.5.0")
   plan1 <- drake_plan(
     w = "w",
@@ -520,6 +570,7 @@ test_with_dir("decorated storr import (#1015)", {
 })
 
 test_with_dir("decorated storr export (#1015)", {
+  skip_on_cran()
   skip_if(getRversion() < "3.5.0")
   plan1 <- drake_plan(
     w = "w",
@@ -545,6 +596,7 @@ test_with_dir("decorated storr export (#1015)", {
 })
 
 test_with_dir("decorated storr import specific targets (#1015)", {
+  skip_on_cran()
   skip_if(getRversion() < "3.5.0")
   plan1 <- drake_plan(
     w = "w",
@@ -570,6 +622,7 @@ test_with_dir("decorated storr import specific targets (#1015)", {
 })
 
 test_with_dir("decorated storr import specific targets (#1015)", {
+  skip_on_cran()
   skip_if(getRversion() < "3.5.0")
   plan1 <- drake_plan(
     w = "w",
@@ -595,6 +648,7 @@ test_with_dir("decorated storr import specific targets (#1015)", {
 })
 
 test_with_dir("safe_get*() methods", {
+  skip_on_cran()
   cache <- new_cache(tempfile())
   for (ns in c(cache$default_namespace, "meta")) {
     expect_equal(cache$safe_get("x", namespace = ns), NA_character_)
@@ -607,8 +661,8 @@ test_with_dir("safe_get*() methods", {
 
 test_with_dir("in-memory representation of disk.frame targets (#1077)", {
   skip_on_cran()
-  skip_if_not_installed("fst")
   skip_if_not_installed("disk.frame")
+  skip_if_not_installed("fst")
   n <- 200
   observations <- data.frame(
     type = sample(letters[seq_len(3)], n, replace = TRUE),
@@ -617,8 +671,8 @@ test_with_dir("in-memory representation of disk.frame targets (#1077)", {
   )
   plan <- drake_plan(
     all_data = target(
-      observations,
-      format = "fst"
+      disk.frame::as.disk.frame(observations, drake_tempfile()),
+      format = "diskframe"
     ),
     result = as.data.frame(head(all_data))
   )
@@ -628,6 +682,7 @@ test_with_dir("in-memory representation of disk.frame targets (#1077)", {
 })
 
 test_with_dir("changes to formats invalidate targets (#1104)", {
+  skip_on_cran()
   skip_if_not_installed("fst")
   df <- data.frame(x = letters, y = letters, stringsAsFactors = FALSE)
   plan <- drake_plan(x = df)
@@ -652,6 +707,7 @@ test_with_dir("changes to formats invalidate targets (#1104)", {
 })
 
 test_with_dir("same with 2 targets (format is NA for x) (#1104)", {
+  skip_on_cran()
   skip_if_not_installed("fst")
   df <- data.frame(x = letters, y = letters, stringsAsFactors = FALSE)
   plan <- drake_plan(x = df, y = x)
@@ -676,6 +732,7 @@ test_with_dir("same with 2 targets (format is NA for x) (#1104)", {
 })
 
 test_with_dir("can suppress the format trigger (#1104)", {
+  skip_on_cran()
   skip_if_not_installed("fst")
   df <- data.frame(x = letters, y = letters, stringsAsFactors = FALSE)
   plan <- drake_plan(x = target(df))
@@ -765,3 +822,56 @@ test_with_dir("qs format (#1121)", {
   expect_false(inherits(ref2, "drake_format"))
   expect_false(inherits(ref2, "drake_format_qs"))
 })
+
+test_with_dir("global rds format (#1124)", {
+  skip_on_cran()
+  skip_if(getRversion() < "3.5.0")
+  plan <- drake_plan(
+    x = list(x = letters, y = letters),
+    y = "rds format"
+  )
+  make(plan, format = "rds")
+  out <- readd(x)
+  exp <- list(x = letters, y = letters)
+  expect_equal(out, exp)
+  expect_equal(readd(y), "rds format")
+  cache <- drake_cache()
+  expect_equal(cache$get_value(cache$get_hash("x")), exp)
+  for (key in c("x", "y")) {
+    ref <- cache$storr$get(key)
+    expect_true(inherits(ref, "drake_format"))
+    expect_true(inherits(ref, "drake_format_rds"))
+    expect_equal(length(ref), 1L)
+    expect_true(nchar(ref) < 100)
+    expect_false(is.list(ref))
+  }
+})
+
+test_with_dir("global rds format + target qs (#1124)", {
+  skip_on_cran()
+  skip_if_not_installed("qs")
+  skip_if(getRversion() < "3.5.0")
+  plan <- drake_plan(
+    x = list(x = letters, y = letters),
+    y = target("qs format", format = "qs")
+  )
+  make(plan, format = "rds")
+  out <- readd(x)
+  exp <- list(x = letters, y = letters)
+  expect_equal(out, exp)
+  expect_equal(readd(y), "qs format")
+  cache <- drake_cache()
+  expect_equal(cache$get_value(cache$get_hash("x")), exp)
+  ref <- cache$storr$get("x")
+  expect_true(inherits(ref, "drake_format"))
+  expect_true(inherits(ref, "drake_format_rds"))
+  expect_equal(length(ref), 1L)
+  expect_true(nchar(ref) < 100)
+  expect_false(is.list(ref))
+  ref <- cache$storr$get("y")
+  expect_true(inherits(ref, "drake_format"))
+  expect_true(inherits(ref, "drake_format_qs"))
+  expect_equal(length(ref), 1L)
+  expect_true(nchar(ref) < 100)
+  expect_false(is.list(ref))
+})
